==> kotlinjs-runtime-extension-0.1.jar: kotlinjs-runtime-extension.js <==
(function (Kotlin) {
  'use strict';
  var _ = Kotlin.defineRootPackage(null, /** @lends _ */ {
    kotlinjs: Kotlin.definePackage(null, /** @lends _.kotlinjs */ {
      runtime: Kotlin.definePackage(null, /** @lends _.kotlinjs.runtime */ {
        container: Kotlin.definePackage(null, /** @lends _.kotlinjs.runtime.container */ {
          Container: Kotlin.createClass(null, function () {
            this.registries_cusr3l$ = Kotlin.modules['stdlib'].kotlin.collections.hashMapOf_eoa9s7$([]);
            this.instances_zfm30q$ = Kotlin.modules['stdlib'].kotlin.collections.hashMapOf_eoa9s7$([]);
          }, /** @lends _.kotlinjs.runtime.container.Container.prototype */ {
            registerInstance: function (name, instance) {
              this.instances_zfm30q$.put_wn2jw4$(name, instance);
              return instance;
            },
            registerSingleton_h6i5tn$: function (name, type, factory, dependencies) {
              var registry = new _.kotlinjs.runtime.container.ServiceRegistry(name, true, type, dependencies, _.kotlinjs.runtime.container.Container.registerSingleton_h6i5tn$f(name, factory, dependencies, this));
              this.registries_cusr3l$.put_wn2jw4$(name, registry);
              return registry;
            },
            registerTransient_h6i5tn$: function (name, type, factory, dependencies) {
              var registry = new _.kotlinjs.runtime.container.ServiceRegistry(name, true, type, dependencies, _.kotlinjs.runtime.container.Container.registerTransient_h6i5tn$f(factory, dependencies, this));
              this.registries_cusr3l$.put_wn2jw4$(name, registry);
              return registry;
            },
            resolveInstance_1: function (factory, dependencies) {
              var destination = new Kotlin.ArrayList(dependencies.length);
              var tmp$0, tmp$1, tmp$2;
              tmp$0 = dependencies, tmp$1 = tmp$0.length;
              for (var tmp$2 = 0; tmp$2 !== tmp$1; ++tmp$2) {
                var item = tmp$0[tmp$2];
                var resolveInstance_1$f$result;
                resolveInstance_1$f$result = this.resolveInstance(item);
                destination.add_za3rmp$(resolveInstance_1$f$result);
              }
              var dependencyInstances = Kotlin.copyToArray(destination);
              var func = factory;
              return func.apply(null, dependencyInstances);
            },
            resolveInstance: function (registry) {
              var tmp$0;
              if (!registry.isSingleton) {
                return registry.factory();
              }
              var tmp$1 = Kotlin.isAny();
              var tmp$2;
              var value = this.instances_zfm30q$.get_za3rmp$(registry.name);
              if (value == null) {
                var answer = registry.factory();
                this.instances_zfm30q$.put_wn2jw4$(registry.name, answer);
                tmp$2 = answer;
              }
               else {
                tmp$2 = value;
              }
              return tmp$1(tmp$0 = tmp$2) ? tmp$0 : Kotlin.throwCCE();
            },
            resolveByName_61zpoe$: function (name) {
              var tmp$0, tmp$1;
              tmp$0 = this.registries_cusr3l$.get_za3rmp$(name);
              if (tmp$0 == null)
                throw new Kotlin.Error("Component '" + name + "' was not found.");
              var registry = tmp$0;
              return this.resolveInstance(Kotlin.isType(tmp$1 = registry, _.kotlinjs.runtime.container.ServiceRegistry) ? tmp$1 : Kotlin.throwCCE());
            },
            resolveByType_4ubtd2$: function (serviceType) {
              first_udlcbx$break: {
                var tmp$0;
                tmp$0 = this.registries_cusr3l$.values.iterator();
                while (tmp$0.hasNext()) {
                  var element = tmp$0.next();
                  if (Kotlin.equals(element.type, serviceType)) {
                    var registry = element;
                    break first_udlcbx$break;
                  }
                }
                throw new Kotlin.NoSuchElementException('Collection contains no element matching the predicate.');
              }
              return this.resolveByName_61zpoe$(registry.name);
            },
            resolveByType: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.resolveByType', function (isT) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.resolveByType_4ubtd2$(type != null ? type : Kotlin.throwNPE());
            }),
            singleton_mjs1mk$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.singleton_mjs1mk$', function (isT, name, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerSingleton_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, []);
            }),
            singleton_ta14wc$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.singleton_ta14wc$', function (isT, name, dependency, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerSingleton_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, [dependency]);
            }),
            singleton_2cuw8$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.singleton_2cuw8$', function (isT, name, dependency1, dependency2, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerSingleton_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, [dependency1, dependency2]);
            }),
            singleton_lwu13s$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.singleton_lwu13s$', function (isT, name, dependency1, dependency2, dependency3, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerSingleton_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, [dependency1, dependency2, dependency3]);
            }),
            transient_mjs1mk$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.transient_mjs1mk$', function (isT, name, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerTransient_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, []);
            }),
            transient_ta14wc$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.transient_ta14wc$', function (isT, name, dependency, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerTransient_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, [dependency]);
            }),
            transient_2cuw8$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.transient_2cuw8$', function (isT, name, dependency1, dependency2, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerTransient_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, [dependency1, dependency2]);
            }),
            transient_lwu13s$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.transient_lwu13s$', function (isT, name, dependency1, dependency2, dependency3, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerTransient_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, [dependency1, dependency2, dependency3]);
            }),
            makeGlobal: function () {
              _.kotlinjs.runtime.container.Container.Companion.instance = this;
            }
          }, /** @lends _.kotlinjs.runtime.container.Container */ {
            registerSingleton_h6i5tn$f: function (closure$name, closure$factory, closure$dependencies, this$Container) {
              return function () {
                return this$Container.registerInstance(closure$name, this$Container.resolveInstance_1(closure$factory, closure$dependencies));
              };
            },
            registerTransient_h6i5tn$f: function (closure$factory, closure$dependencies, this$Container) {
              return function () {
                return this$Container.resolveInstance_1(closure$factory, closure$dependencies);
              };
            },
            Companion: Kotlin.createObject(null, null),
            object_initializer$: function () {
              _.kotlinjs.runtime.container.Container.Companion;
            }
          }),
          ServiceRegistry: Kotlin.createClass(null, function (name, isSingleton, type, dependencies, factory) {
            this.name = name;
            this.isSingleton = isSingleton;
            this.type = type;
            this.dependencies = dependencies;
            this.factory = factory;
          }, /** @lends _.kotlinjs.runtime.container.ServiceRegistry.prototype */ {
            invoke: function () {
              return this.factory();
            }
          })
        }),
        decorator: Kotlin.definePackage(null, /** @lends _.kotlinjs.runtime.decorator */ {
          decorate: function (decorators, target, propertyName) {
            var tmp$0;
            if (propertyName === void 0)
              propertyName = null;
            {
              var __decorate = this && this.__decorate || function (decorators, target, key, desc) {
                var c = arguments.length, r = c < 3 ? target : desc === null ? (desc = Object.getOwnPropertyDescriptor(target, key)) : desc, d;
                if (typeof Reflect === 'object' && typeof Reflect.decorate === 'function')
                  r = Reflect.decorate(decorators, target, key, desc);
                else
                  for (var i = decorators.length - 1; i >= 0; i--)
                    if (d = decorators[i])
                      r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
                return c > 3 && (r && Object.defineProperty(target, key, r)), r;
              };
              var __metadata = this && this.__metadata || function (k, v) {
                if (typeof Reflect === 'object' && typeof Reflect.metadata === 'function')
                  return Reflect.metadata(k, v);
              };
              if (propertyName) {
                return __decorate(decorators, target.prototype, propertyName, Object.getOwnPropertyDescriptor(target.prototype, propertyName));
              }
              return __decorate(decorators, target);
            }
          },
          addClassDecorators_dua6l2$: function ($receiver, decorators) {
            var type = $receiver;
            var result = _.kotlinjs.runtime.decorator.decorate(decorators, type);
            return result;
          }
        }),
        extension: Kotlin.definePackage(null, /** @lends _.kotlinjs.runtime.extension */ {
          JsonSerializable: Kotlin.createTrait(null),
          typeOf: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.extension.typeOf', function (isT) {
            var type = null;
            {
              var tmp = Kotlin.isType;
              Kotlin.isType = function (a, b) {
                type = b;
              };
            }
            isT(null);
            Kotlin.isType = tmp;
            return type != null ? type : Kotlin.throwNPE();
          }),
          fullNameOf: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.extension.fullNameOf', function (isT) {
            var f = function () {
              isT(N$v0 - R0$iv);
            }.toString();
            return _.kotlinjs.runtime.extension.extractFullName_61zpoe$(f);
          }),
          nameOf: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.extension.nameOf', function (isT) {
            var f = function () {
              isT(N$v0 - R0$iv);
            }.toString();
            return _.kotlinjs.runtime.extension.extractSimpleName_61zpoe$(f);
          }),
          extractFullName_61zpoe$: function (foundTypeName) {
            var s = '(N$v0 - R0$iv, ';
            var i = Kotlin.modules['stdlib'].kotlin.text.indexOf_30chhv$(foundTypeName, s);
            var e = Kotlin.modules['stdlib'].kotlin.text.lastIndexOf_30chhv$(foundTypeName, ');');
            if (i === -1 || e === -1)
              return null;
            var typeName = foundTypeName.substring(i + s.length, e);
            return Kotlin.modules['stdlib'].kotlin.text.startsWith_41xvrb$(typeName, '_.') ? typeName.substring(2) : typeName;
          },
          extractSimpleName_61zpoe$: function (f) {
            var tmp$0;
            var name = _.kotlinjs.runtime.extension.extractFullName_61zpoe$(f);
            var lastDotIndex = (tmp$0 = name != null ? Kotlin.modules['stdlib'].kotlin.text.lastIndexOf_ilfvta$(name, '.') : null) != null ? tmp$0 : -1;
            return lastDotIndex > 0 ? name != null ? name.substring(lastDotIndex + 1) : null : name;
          },
          createObjectOf_lm9z1s$: function (populate) {
            if (populate === void 0)
              populate = null;
            var obj = {};
            if (populate != null) {
              populate.call(obj);
            }
            return obj;
          },
          mergeOf_wn2jw4$: function (target, source) {
            var copy = _.kotlinjs.runtime.extension.createObjectOf_lm9z1s$();
            Object.assign(copy, target, source);
            return copy;
          },
          extendObject_febbmr$: function (source, populate) {
            var copy = _.kotlinjs.runtime.extension.createObjectOf_lm9z1s$();
            Object.assign(copy, source);
            populate.call(copy);
            return copy;
          },
          createJsonObjectOf_lm9z1s$: function (populate) {
            if (populate === void 0)
              populate = null;
            var obj = _.kotlinjs.runtime.extension.createObjectOf_lm9z1s$(populate);
            return obj;
          }
        })
      })
    })
  });
  Kotlin.defineModule('kotlinjs-runtime-extension', _);
}(Kotlin));

==> kotlinjs-runtime-extension-0.1.1.jar: kotlinjs-runtime-extension.js <==
(function (Kotlin) {
  'use strict';
  var _ = Kotlin.defineRootPackage(null, /** @lends _ */ {
    kotlinjs: Kotlin.definePackage(null, /** @lends _.kotlinjs */ {
      runtime: Kotlin.definePackage(null, /** @lends _.kotlinjs.runtime */ {
        container: Kotlin.definePackage(null, /** @lends _.kotlinjs.runtime.container */ {
          Container: Kotlin.createClass(null, function () {
            this.registries_cusr3l$ = Kotlin.modules['stdlib'].kotlin.collections.hashMapOf_eoa9s7$([]);
            this.instances_zfm30q$ = Kotlin.modules['stdlib'].kotlin.collections.hashMapOf_eoa9s7$([]);
          }, /** @lends _.kotlinjs.runtime.container.Container.prototype */ {
            registerInstance: function (name, instance) {
              this.instances_zfm30q$.put_wn2jw4$(name, instance);
              return instance;
            },
            registerSingleton_h6i5tn$: function (name, type, factory, dependencies) {
              var registry = new _.kotlinjs.runtime.container.ServiceRegistry(name, true, type, dependencies, _.kotlinjs.runtime.container.Container.registerSingleton_h6i5tn$f(name, factory, dependencies, this));
              this.registries_cusr3l$.put_wn2jw4$(name, registry);
              return registry;
            },
            registerTransient_h6i5tn$: function (name, type, factory, dependencies) {
              var registry = new _.kotlinjs.runtime.container.ServiceRegistry(name, true, type, dependencies, _.kotlinjs.runtime.container.Container.registerTransient_h6i5tn$f(factory, dependencies, this));
              this.registries_cusr3l$.put_wn2jw4$(name, registry);
              return registry;
            },
            resolveInstance_1: function (factory, dependencies) {
              var destination = new Kotlin.ArrayList(dependencies.length);
              var tmp$3, tmp$1, tmp$2;
              tmp$3 = dependencies, tmp$1 = tmp$3.length;
              for (var tmp$2 = 0; tmp$2 !== tmp$1; ++tmp$2) {
                var item = tmp$3[tmp$2];
                destination.add_za3rmp$(this.resolveInstance(item));
              }
              var dependencyInstances = Kotlin.copyToArray(destination);
              var func = factory;
              return func.apply(null, dependencyInstances);
            },
            resolveInstance: function (registry) {
              var tmp$0;
              if (!registry.isSingleton) {
                return registry.factory();
              }
              var $receiver = this.instances_zfm30q$;
              var key = registry.name;
              var tmp$2;
              var value = $receiver.get_za3rmp$(key);
              if (value == null) {
                var answer = registry.factory();
                $receiver.put_wn2jw4$(key, answer);
                tmp$2 = answer;
              }
               else {
                tmp$2 = value;
              }
              return (tmp$0 = tmp$2) != null ? tmp$0 : Kotlin.throwCCE();
            },
            resolveByName_61zpoe$: function (name) {
              var tmp$0, tmp$1;
              tmp$0 = this.registries_cusr3l$.get_za3rmp$(name);
              if (tmp$0 == null)
                throw new Kotlin.Error("Component '" + name + "' was not found.");
              var registry = tmp$0;
              return this.resolveInstance(Kotlin.isType(tmp$1 = registry, _.kotlinjs.runtime.container.ServiceRegistry) ? tmp$1 : Kotlin.throwCCE());
            },
            resolveByType_4ubtd2$: function (serviceType) {
              var $receiver = this.registries_cusr3l$.values;
              first_udlcbx$break: {
                var tmp$0;
                tmp$0 = $receiver.iterator();
                while (tmp$0.hasNext()) {
                  var element = tmp$0.next();
                  if (Kotlin.equals(element.type, serviceType)) {
                    var registry = element;
                    break first_udlcbx$break;
                  }
                }
                throw new Kotlin.NoSuchElementException('Collection contains no element matching the predicate.');
              }
              return this.resolveByName_61zpoe$(registry.name);
            },
            resolveByType: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.resolveByType', function (isT) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.resolveByType_4ubtd2$(type != null ? type : Kotlin.throwNPE());
            }),
            singleton_mjs1mk$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.singleton_mjs1mk$', function (isT, name, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerSingleton_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, []);
            }),
            singleton_ta14wc$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.singleton_ta14wc$', function (isT, name, dependency, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerSingleton_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, [dependency]);
            }),
            singleton_2cuw8$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.singleton_2cuw8$', function (isT, name, dependency1, dependency2, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerSingleton_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, [dependency1, dependency2]);
            }),
            singleton_lwu13s$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.singleton_lwu13s$', function (isT, name, dependency1, dependency2, dependency3, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerSingleton_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, [dependency1, dependency2, dependency3]);
            }),
            transient_mjs1mk$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.transient_mjs1mk$', function (isT, name, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerTransient_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, []);
            }),
            transient_ta14wc$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.transient_ta14wc$', function (isT, name, dependency, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerTransient_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, [dependency]);
            }),
            transient_2cuw8$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.transient_2cuw8$', function (isT, name, dependency1, dependency2, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerTransient_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, [dependency1, dependency2]);
            }),
            transient_lwu13s$: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.container.Container.transient_lwu13s$', function (isT, name, dependency1, dependency2, dependency3, factory) {
              var type = null;
              {
                var tmp = Kotlin.isType;
                Kotlin.isType = function (a, b) {
                  type = b;
                };
              }
              isT(null);
              Kotlin.isType = tmp;
              return this.registerTransient_h6i5tn$(name, type != null ? type : Kotlin.throwNPE(), factory, [dependency1, dependency2, dependency3]);
            }),
            makeGlobal: function () {
              _.kotlinjs.runtime.container.Container.Companion.instance = this;
            }
          }, /** @lends _.kotlinjs.runtime.container.Container */ {
            registerSingleton_h6i5tn$f: function (closure$name, closure$factory, closure$dependencies, this$Container) {
              return function () {
                return this$Container.registerInstance(closure$name, this$Container.resolveInstance_1(closure$factory, closure$dependencies));
              };
            },
            registerTransient_h6i5tn$f: function (closure$factory, closure$dependencies, this$Container) {
              return function () {
                return this$Container.resolveInstance_1(closure$factory, closure$dependencies);
              };
            },
            Companion: Kotlin.createObject(null, null),
            object_initializer$: function () {
              _.kotlinjs.runtime.container.Container.Companion;
            }
          }),
          ServiceRegistry: Kotlin.createClass(null, function (name, isSingleton, type, dependencies, factory) {
            this.name = name;
            this.isSingleton = isSingleton;
            this.type = type;
            this.dependencies = dependencies;
            this.factory = factory;
          }, /** @lends _.kotlinjs.runtime.container.ServiceRegistry.prototype */ {
            invoke: function () {
              return this.factory();
            }
          })
        }),
        decorator: Kotlin.definePackage(null, /** @lends _.kotlinjs.runtime.decorator */ {
          decorate: function (decorators, target, propertyName) {
            var tmp$0;
            if (propertyName === void 0)
              propertyName = null;
            {
              var __decorate = this && this.__decorate || function (decorators, target, key, desc) {
                var c = arguments.length, r = c < 3 ? target : desc === null ? (desc = Object.getOwnPropertyDescriptor(target, key)) : desc, d;
                if (typeof Reflect === 'object' && typeof Reflect.decorate === 'function')
                  r = Reflect.decorate(decorators, target, key, desc);
                else
                  for (var i = decorators.length - 1; i >= 0; i--)
                    if (d = decorators[i])
                      r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
                return c > 3 && (r && Object.defineProperty(target, key, r)), r;
              };
              var __metadata = this && this.__metadata || function (k, v) {
                if (typeof Reflect === 'object' && typeof Reflect.metadata === 'function')
                  return Reflect.metadata(k, v);
              };
              if (propertyName) {
                return __decorate(decorators, target.prototype, propertyName, Object.getOwnPropertyDescriptor(target.prototype, propertyName));
              }
              return __decorate(decorators, target);
            }
          },
          addClassDecorators_dua6l2$: function ($receiver, decorators) {
            var type = $receiver;
            var result = _.kotlinjs.runtime.decorator.decorate(decorators, type);
            return result;
          }
        }),
        extension: Kotlin.definePackage(null, /** @lends _.kotlinjs.runtime.extension */ {
          JsonSerializable: Kotlin.createTrait(null),
          typeOf: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.extension.typeOf', function (isT) {
            var type = null;
            {
              var tmp = Kotlin.isType;
              Kotlin.isType = function (a, b) {
                type = b;
              };
            }
            isT(null);
            Kotlin.isType = tmp;
            return type != null ? type : Kotlin.throwNPE();
          }),
          fullNameOf: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.extension.fullNameOf', function (isT) {
            var f = function () {
              isT(N$v0 - R0$iv);
            }.toString();
            return _.kotlinjs.runtime.extension.extractFullName_61zpoe$(f);
          }),
          nameOf: Kotlin.defineInlineFunction('kotlinjs-runtime-extension.kotlinjs.runtime.extension.nameOf', function (isT) {
            var f = function () {
              isT(N$v0 - R0$iv);
            }.toString();
            return _.kotlinjs.runtime.extension.extractSimpleName_61zpoe$(f);
          }),
          extractFullName_61zpoe$: function (foundTypeName) {
            var s = '(N$v0 - R0$iv, ';
            var i = Kotlin.modules['stdlib'].kotlin.text.indexOf_30chhv$(foundTypeName, s);
            var e = Kotlin.modules['stdlib'].kotlin.text.lastIndexOf_30chhv$(foundTypeName, ');');
            if (i === -1 || e === -1)
              return null;
            var typeName = foundTypeName.substring(i + s.length, e);
            return Kotlin.modules['stdlib'].kotlin.text.startsWith_41xvrb$(typeName, '_.') ? typeName.substring(2) : typeName;
          },
          extractSimpleName_61zpoe$: function (f) {
            var tmp$0;
            var name = _.kotlinjs.runtime.extension.extractFullName_61zpoe$(f);
            var lastDotIndex = (tmp$0 = name != null ? Kotlin.modules['stdlib'].kotlin.text.lastIndexOf_ilfvta$(name, '.') : null) != null ? tmp$0 : -1;
            return lastDotIndex > 0 ? name != null ? name.substring(lastDotIndex + 1) : null : name;
          },
          createObjectOf_lm9z1s$: function (populate) {
            if (populate === void 0)
              populate = null;
            var obj = {};
            if (populate != null) {
              populate.call(obj);
            }
            return obj;
          },
          mergeOf_wn2jw4$: function (target, source) {
            var copy = _.kotlinjs.runtime.extension.createObjectOf_lm9z1s$();
            Object.assign(copy, target, source);
            return copy;
          },
          extendObject_febbmr$: function (source, populate) {
            var copy = _.kotlinjs.runtime.extension.createObjectOf_lm9z1s$();
            Object.assign(copy, source);
            populate.call(copy);
            return copy;
          },
          createJsonObjectOf_lm9z1s$: function (populate) {
            if (populate === void 0)
              populate = null;
            var obj = _.kotlinjs.runtime.extension.createObjectOf_lm9z1s$(populate);
            return obj;
          }
        })
      })
    })
  });
  Kotlin.defineModule('kotlinjs-runtime-extension', _);
}(Kotlin));
